@@ -1,7 +1,5 @@
 /*
- *  Xarchiver
- *
- *  Copyright (C) 2005 Giuseppe Torelli - Colossus
+ *  Copyright (C) 2005 Giuseppe Torelli - <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,16 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef SEVENZIP_H
 #define SEVENZIP_H
 
- #include <gtk/gtk.h>
- #include "callbacks.h"
- #include "interface.h"
- #include "support.h"
- #include "main.h"
+#include <gtk/gtk.h>
+#include "callbacks.h"
+#include "interface.h"
+#include "archive.h"
+#include "string_utils.h"
 
-void Open7Zip ( gboolean mode , gchar *path );
-static gboolean SevenZipOpen (GIOChannel *ioc, GIOCondition cond, gpointer data);
+void Open7Zip ( XArchive *archive );
 #endif
