@@ -1,7 +1,5 @@
 /*
- *  Xarchiver
- *
- *  Copyright (C) 2005 Giuseppe Torelli - Colossus
+ *  Copyright (C) 2006 Giuseppe Torelli - <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,10 +21,20 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include "interface.h"
+#include "new_dialog.h"
+#include "archive.h"
+#include "callbacks.h"
 
 GtkWidget *MainWindow;
+GList *ArchiveSuffix;
+GList *ArchiveType;
+const gchar *locale;
 
 void GetAvailableCompressors();
-void SetButtonState ( gboolean, gboolean,gboolean,gboolean,gboolean );
-gboolean ParseCommandLine ( char *param );
+void xa_set_button_state ( gboolean, gboolean,gboolean,gboolean, gboolean, gboolean );
+gchar *get_argv_filename(const gchar *filename);
+gboolean SpawnSyncCommand ( gchar *command );
+XArchive *xa_init_structure_from_cmd_line (char *filename);
 #endif /* MAIN_H */
+
